summaryrefslogtreecommitdiffstats
path: root/c/src/lib/libcpu/powerpc/mpc55xx/include/dspi.h
diff options
context:
space:
mode:
authorThomas Doerfler <Thomas.Doerfler@embedded-brains.de>2009-07-21 08:38:04 +0000
committerThomas Doerfler <Thomas.Doerfler@embedded-brains.de>2009-07-21 08:38:04 +0000
commitd374492cc69fa8bd041852d868ae379b79c59ba4 (patch)
tree14fa506e5c9564844d5fa0436ae4d2d456a74dda /c/src/lib/libcpu/powerpc/mpc55xx/include/dspi.h
parentUpdate to binutils-2.19.51-20090721. (diff)
downloadrtems-d374492cc69fa8bd041852d868ae379b79c59ba4.tar.bz2
Update for MPC55XX changes
Diffstat (limited to '')
-rw-r--r--c/src/lib/libcpu/powerpc/mpc55xx/include/dspi.h45
1 files changed, 16 insertions, 29 deletions
diff --git a/c/src/lib/libcpu/powerpc/mpc55xx/include/dspi.h b/c/src/lib/libcpu/powerpc/mpc55xx/include/dspi.h
index 4ad2479851..fd4b7fe414 100644
--- a/c/src/lib/libcpu/powerpc/mpc55xx/include/dspi.h
+++ b/c/src/lib/libcpu/powerpc/mpc55xx/include/dspi.h
@@ -29,6 +29,8 @@
#include <rtems/libi2c.h>
+#include <mpc55xx/edma.h>
+
#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */
@@ -64,7 +66,7 @@ typedef struct {
/**
* @brief Selects SPI master or slave mode.
*/
- int master;
+ bool master;
/**
* @brief Data for the Push Register.
@@ -72,50 +74,35 @@ typedef struct {
union DSPI_PUSHR_tag push_data;
/**
* @brief eDMA channel for transmission.
*
- * The channel is fixed to particular DSPI.
+ * The channel is fixed to a particular DSPI.
*/
- int edma_channel_transmit;
+ mpc55xx_edma_channel_entry edma_transmit;
/**
* @brief eDMA channel to generate the push data.
*
- * You can choose any available channel.
+ * You can choose every available channel.
*/
- int edma_channel_push;
+ mpc55xx_edma_channel_entry edma_push;
/**
* @brief eDMA channel for receiving.
*
- * The channel is fixed to particular DSPI.
- */
- int edma_channel_receive;
-
- /**
- * @brief Semaphore ID for a transmit update.
- */
- rtems_id edma_channel_transmit_update;
-
- /**
- * @brief Semaphore ID for a receive update.
+ * The channel is fixed to a particular DSPI.
*/
- rtems_id edma_channel_receive_update;
+ mpc55xx_edma_channel_entry edma_receive;
/**
- * @brief Transmit error status.
- */
- uint32_t edma_channel_transmit_error;
-
- /**
- * @brief Receive error status.
+ * @brief Idle character transmitted in read only mode.
*/
- uint32_t edma_channel_receive_error;
+ uint32_t idle_char;
/**
- * @brief Idle character transmitted in read only mode.
+ * @brief Current baud.
*/
- uint32_t idle_char;
+ uint32_t baud;
} mpc55xx_dspi_bus_entry;
/**
@@ -72,50 +74,35 @@ typedef struct {
union DSPI_PUSHR_tag push_data;
/**
- * @brief eDMA channel for transmission.
+ * @brief eDMA entry for transmission.
*
@@ -72,50 +74,35 @@ typedef struct {
/**
- * @brief eDMA channel to generate the push data.
+ * @brief eDMA entry for push data generation.
*
@@ -72,50 +74,35 @@ typedef struct {
/**
- * @brief eDMA channel for receiving.
+ * @brief eDMA entry for receiving.
*